import express from "express";
import {
  markAttendance,
  getAttendanceBySalesCoordinator,
  getTodayAttendance,
  AdmingetAttendanceBySalesCoordinator,
} from "./AttandanceSalesCoordinatorController.js";
import { isAuthenticatedSalesCoOrdinator } from "../../middlewares/SalesCoOrdinatorAuth.js";
import { authorizeRoles, isAuthenticatedUser } from "../../middlewares/auth.js";

const router = express.Router();

// Place more specific routes first

// Route to get today's attendance for admin
router.get(
  "/attendance/today",
  isAuthenticatedUser,
  authorizeRoles("admin"),
  getTodayAttendance
);

// Route to mark attendance
router.post("/attendance", isAuthenticatedSalesCoOrdinator, markAttendance);

// Route to get attendance for the logged-in sales coordinator
router.get(
  "/attendance",
  isAuthenticatedSalesCoOrdinator,
  getAttendanceBySalesCoordinator
);

// Admin route to get attendance by sales coordinator ID
router.get(
  "/attendance/:id",
  isAuthenticatedUser,
  authorizeRoles("admin"),
  AdmingetAttendanceBySalesCoordinator
);

export default router;
